@@ -4,7 +4,7 @@ Main interface for apigateway service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_apigateway import (
         APIGatewayClient,
         Client,
@@ -28,10 +28,8 @@ Usage::
         GetVpcLinksPaginator,
     )
 
-    session = boto3.Session()
-
-    client: APIGatewayClient = boto3.client("apigateway")
-    session_client: APIGatewayClient = session.client("apigateway")
+    session = Session()
+    client: APIGatewayClient = session.client("apigateway")
 
     get_api_keys_paginator: GetApiKeysPaginator = client.get_paginator("get_api_keys")
     get_authorizers_paginator: GetAuthorizersPaginator = client.get_paginator("get_authorizers")
